@@ -3,7 +3,7 @@
 #' @description Display formatted ANOVA table in command window.
 #'
 #' @param ezObj Output from ezANOVA
-#' @param name Required for heading
+#' @param caption Required for heading
 #'
 #' @return NULL
 #'
@@ -23,10 +23,12 @@
 #' aovDispTable(aovRT)
 #'
 #' @export
-aovDispTable <- function(ezObj, name=sys.call()) {
-  name <- paste0("ANOVA:", unlist(lapply(name[2], as.character)))
+aovDispTable <- function(ezObj, caption=sys.call()) {
+  if (!is.character(caption)){
+    caption <- paste0("ANOVA:", unlist(lapply(caption[2], as.character)))
+  }
   width <- max(apply(ezObj$ANOVA, 1, function(x) sum(nchar(x))))
-  print(cli::rule(line = 2, center = crayon::black(name), width = width + 13))
+  print(cli::rule(line = 2, center = crayon::black(caption), width = width + 13))
   print(ezObj$ANOVA, row.names = FALSE)
   print(cli::rule(width = width + 13))
 }
