@@ -34,12 +34,12 @@ pValueString <- function(pVal, nsmall = 2){
   }
 
   if (pVal >= 0.01) {
-    string <- paste0("\\\\emph{p} = ", format(round(pVal, nsmall), nsmall = nsmall))
+    string <- paste0("\\emph{p} = ", format(round(pVal, nsmall), nsmall = nsmall))
     string <- gsub("0\\.", ".", string)
   } else if (pVal >= 0.001 & pVal < 0.01) {
-    string <- paste0("\\\\emph{p}", " < .01")
+    string <- paste0("\\emph{p}", " < .01")
   } else if (pVal < 0.001) {
-    string <- paste0("\\\\emph{p}", " < .001")
+    string <- paste0("\\emph{p}", " < .001")
   }
 
   return(string)
