@@ -16,8 +16,8 @@ test_that("fValueString", {
                    return_aov = TRUE, detailed = TRUE)
   aovRT <- aovTable(aovRT)
 
-  expect_equal(fValueString(aovRT, "Comp"), "\\\\emph{F}(1, 49) = 4.37")
-  expect_equal(fValueString(aovRT, "Side"), "\\\\emph{F}(1, 49) = 0.32")
-  expect_equal(fValueString(aovRT, "Comp:Side"), "\\\\emph{F}(1, 49) = 0.49")
+  expect_equal(fValueString(aovRT, "Comp"), "\\emph{F}(1, 49) = 4.37")
+  expect_equal(fValueString(aovRT, "Side"), "\\emph{F}(1, 49) = 0.32")
+  expect_equal(fValueString(aovRT, "Comp:Side"), "\\emph{F}(1, 49) = 0.49")
 
 })
